==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/gn/activity-stream-strings.js <==
// Note - this is a generated gn file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Tendayke Pyahu",
  "header_top_sites": "Tenda Ojehechavéva",
  "header_highlights": "Mba'eporãitéva",
  "header_recommended_by": "{provider} he'i ndéve reike hag̃ua",
  "context_menu_button_sr": "Embojuruja poravorã {title} peg̃uarã",
  "section_context_menu_button_sr": "Eike poravorã vore jereguávape",
  "type_label_visited": "Jeikepyre",
  "type_label_bookmarked": "Oñeñongatuva'ekue techaukaháramo",
  "type_label_recommended": "Ojehechajepíva",
  "type_label_pocket": "Pocket-pe ñongatupyre",
  "type_label_downloaded": "Mboguejypyre",
  "menu_action_bookmark": "Techaukaha",
  "menu_action_remove_bookmark": "Techaukaha Mboguete",
  "menu_action_open_new_window": "Jeike Ovetã Pyahúpe",
  "menu_action_open_private_window": "Jeike Ovetã Ñemi Pyahúpe",
  "menu_action_dismiss": "Emboyke",
  "menu_action_delete": "Tembiasakue Rysýigui Ñeguenohẽ",
  "menu_action_pin": "Mboja",
  "menu_action_unpin": "Mboja'ỹ",
  "confirm_history_delete_p1": "Añetehápepa renohẽse oimeraẽva mba'e ko toguepegua tembiasakue rysýigui?",
  "confirm_history_delete_notice_p2": "Ko ojejapóva ndaikatuvéima oñemboguevi.",
  "menu_action_save_to_pocket": "Eñongatu Pocket-pe",
  "menu_action_delete_pocket": "Embogue Pocket-pe",
  "menu_action_archive_pocket": "Eñongatu Pocket-pe",
  "menu_action_show_file_mac_os": "Ehechauka Finder-pe",
  "menu_action_show_file_windows": "Embojuruja ñongatuha guerekopýva",
  "menu_action_show_file_linux": "Embojuruja ñongatuha guerekopýva",
  "menu_action_show_file_default": "Ehechauka marandurenda",
  "menu_action_open_file": "Embojuruja marandurenda",
  "menu_action_copy_download_link": "Emonguatia juajuha kundaharape",
  "menu_action_go_to_download_page": "Eho ñemboguejyha kuatiaroguépe",
  "menu_action_remove_download": "Emboguepa tembiasakuégui",
  "search_button": "Eheka",
  "search_header": "Eheka {search_engine_name} ndive",
  "search_web_placeholder": "Ñandutivevépe Jeheka",
  "section_disclaimer_topstories": "Mba'erechapyrã ñandutivevepegua ojeiporavóva ndéve g̃uarã ojejesareko rupi remoñe'ẽva jepi rehe. Pocket guive ha'éva ko'ág̃a Mozilla mba'e.",
  "section_disclaimer_topstories_linktext": "Eikuaave mba'éichapa oiko.",
  "section_disclaimer_topstories_buttontext": "Oĩma, hesakãma chéve",
  "prefs_home_header": "Kuatiarogue retepy Firefox ñepyrũháme",
  "prefs_home_description": "Eiporavo mba’e retepýpa eipota Firefox mba’erechaha ñepyrũháme.",
  "prefs_content_discovery_header": "Firefox kuatiarogue ñepyrũ",
  "prefs_content_discovery_description": "Content Discovery in Firefox Home allows you to discover high-quality, relevant articles from across the web.",
  "prefs_content_discovery_button": "Turn Off Content Discovery",
  "prefs_section_rows_option": "{num} rysýi; {num} rysýi",
  "prefs_search_header": "Ñandutípe jeheka",
  "prefs_topsites_description": "Umi tenda ojeikeveha",
  "prefs_topstories_description2": "Iporãvéva ñanduti retepy, oñemomba’éva ndéve g̃uarã",
  "prefs_topstories_options_sponsored_label": "Tembiasakue jehepyme'ẽguáva",
  "prefs_topstories_sponsored_learn_more": "Kuaave",
  "prefs_highlights_description": "Tenda jeporavopy eñongatu térã eike hague",
  "prefs_highlights_options_visited_label": "Tenda jeikepyre",
  "prefs_highlights_options_download_label": "Oñemboguejy ramovéva",
  "prefs_highlights_options_pocket_label": "Kuatiarogue ñongatupyre Pocket-pe",
  "prefs_snippets_description": "Mozilla ha Firefox ñembohekopyahu",
  "settings_pane_button_label": "Eñemomba'e ne Tendayke Pyahu roguére",
  "settings_pane_topsites_header": "Tenda Ojeikevéva",
  "settings_pane_highlights_header": "Mba'erechapyrã",
  "settings_pane_highlights_options_bookmarks": "Techaukaha",
  "settings_pane_snippets_header": "Mba'epehẽ",
  "edit_topsites_button_text": "Mbosako'i",
  "edit_topsites_edit_button": "Embosako'i ko tenda",
  "topsites_form_add_header": "Tenda Pyahu Ojeikevéva",
  "topsites_form_edit_header": "Tenda Ojeikevéva Mbosako'i",
  "topsites_form_title_label": "Teratee",
  "topsites_form_title_placeholder": "Ehai herarã",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL ra’anga ñemomba’etepyre",
  "topsites_form_url_placeholder": "Ehai térã emboja peteĩ URL",
  "topsites_form_use_image_link": "Ta’anga ñemomba’etepyre…",
  "topsites_form_preview_button": "Jehecha ypy",
  "topsites_form_add_button": "Embojoapy",
  "topsites_form_save_button": "Ñongatu",
  "topsites_form_cancel_button": "Heja",
  "topsites_form_url_validation": "Oñeikotevẽ URL oiko porãva",
  "topsites_form_image_validation": "Ta’anga nehenyhẽkuái. Eipuru peteĩ URL iñambuéva.",
  "pocket_read_more": "Ñe'ẽmbyrã Ojehayhuvéva:",
  "pocket_read_even_more": "Ahechaseve Mombe'upy",
  "pocket_more_reccommendations": "Hetave je’eporã",
  "pocket_how_it_works": "Mba’éichapa omba’apo",
  "pocket_cta_button": "Eguereko Pocket",
  "pocket_cta_text": "Eñongatu umi eipotáva tembiasakue Pocket-pe ha emombarete ne akã ñemoñe’ẽ ha’evévape.",
  "highlights_empty_state": "Eñepyrũ eikundaha ha rohechaukáta ndéve mba'ehai, mba'erecharã oĩva ha ambue ñandutirenda reikeva'ekue ýrõ rembotechaukava'ekue.",
  "topstories_empty_state": "Ko'ág̃a reikuaapáma ipyahúva. Eikejey ag̃ave ápe eikuaávo mombe'upy pyahu {provider} oikuave'ẽva ndéve. Ndaikatuvéima reha'ãrõ? Eiporavo peteĩ ñe'ẽmbyrã ha emoñe'ẽve oĩvéva ñande yvy ape ári.",
  "manual_migration_explanation2": "Eipuru Firefox reheve techaukaha, tembiasakue ha ñe'ẽñemi ambue kundaharapegua.",
  "manual_migration_cancel_button": "Ag̃amiénte",
  "manual_migration_import_button": "Egueroike Ko'ág̃a",
  "error_fallback_default_info": "Ema'ẽ, mba’épa osẽvai henyhẽnguévo ko tetepy.",
  "error_fallback_default_refresh_suggestion": "Kuatiarogue mbopiro’y eñepyrũjey hag̃ua",
  "section_menu_action_remove_section": "Emboguete vore",
  "section_menu_action_collapse_section": "Embopytupa vore",
  "section_menu_action_expand_section": "Emyasãi vore",
  "section_menu_action_manage_section": "Eñagareko vorére",
  "section_menu_action_manage_webext": "Emongu'e jepysokue",
  "section_menu_action_add_topsite": "Embojuaju Tenda ojeikeveha",
  "section_menu_action_add_search_engine": "Embojuaju hekaha",
  "section_menu_action_move_up": "Jupi",
  "section_menu_action_move_down": "Guejy",
  "section_menu_action_privacy_notice": "Marandu’i ñemiguáva",
  "firstrun_title": "Egueraha Firefox nendive",
  "firstrun_content": "Eike nde techaukaha, tembiasakue, ñe’ẽñemi ha ambueve ñemoĩporã opaite nde mba’e’okápe.",
  "firstrun_learn_more_link": "Eikuaave Firefox Accounts rehegua",
  "firstrun_form_header": "Emoinge ne ñandutiveve",
  "firstrun_form_sub_header": "eike hag̃ua Firefox Sync-pe.",
  "firstrun_email_input_placeholder": "Ñandutiveve",
  "firstrun_invalid_input": "Eikotevẽ peteĩ ñanduti veve oikóva",
  "firstrun_extra_legal_links": "Ejapóva, emoneĩ ko'ã {terms} ha {privacy}.",
  "firstrun_terms_of_service": "Mba'epytyvõrã ñemboguata",
  "firstrun_privacy_notice": "Ñemigua purureko",
  "firstrun_continue_to_login": "Eku'ejey",
  "firstrun_skip_login": "Ehejánte kóva",
  "context_menu_title": "Eike poravorãme"
};

==> thunderbird_68.10.0.orig.tar.xz: thunderbird-68.10.0/browser/components/newtab/prerendered/locales/gn/activity-stream-strings.js <==
// Note - this is a generated gn file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Tendayke Pyahu",
  "header_top_sites": "Tenda Ojehechavéva",
  "header_highlights": "Mba'eporãitéva",
  "header_recommended_by": "{provider} he'i ndéve reike hag̃ua",
  "context_menu_button_sr": "Embojuruja poravorã {title} peg̃uarã",
  "section_context_menu_button_sr": "Eike poravorã vore jereguávape",
  "type_label_visited": "Jeikepyre",
  "type_label_bookmarked": "Oñeñongatuva'ekue techaukaháramo",
  "type_label_recommended": "Ojehechajepíva",
  "type_label_pocket": "Pocket-pe ñongatupyre",
  "type_label_downloaded": "Mboguejypyre",
  "menu_action_bookmark": "Techaukaha",
  "menu_action_remove_bookmark": "Techaukaha Mboguete",
  "menu_action_open_new_window": "Jeike Ovetã Pyahúpe",
  "menu_action_open_private_window": "Jeike Ovetã Ñemi Pyahúpe",
  "menu_action_dismiss": "Emboyke",
  "menu_action_delete": "Tembiasakue Rysýigui Ñeguenohẽ",
  "menu_action_pin": "Mboja",
  "menu_action_unpin": "Mboja'ỹ",
  "confirm_history_delete_p1": "Añetehápepa renohẽse oimeraẽva mba'e ko toguepegua tembiasakue rysýigui?",
  "confirm_history_delete_notice_p2": "Ko ojejapóva ndaikatuvéima oñemboguevi.",
  "menu_action_save_to_pocket": "Eñongatu Pocket-pe",
  "menu_action_delete_pocket": "Embogue Pocket-pe",
  "menu_action_archive_pocket": "Eñongatu Pocket-pe",
  "menu_action_show_file_mac_os": "Ehechauka Finder-pe",
  "menu_action_show_file_windows": "Embojuruja ñongatuha guerekopýva",
  "menu_action_show_file_linux": "Embojuruja ñongatuha guerekopýva",
  "menu_action_show_file_default": "Ehechauka marandurenda",
  "menu_action_open_file": "Embojuruja marandurenda",
  "menu_action_copy_download_link": "Emonguatia juajuha kundaharape",
  "menu_action_go_to_download_page": "Eho ñemboguejyha kuatiaroguépe",
  "menu_action_remove_download": "Emboguepa tembiasakuégui",
  "search_button": "Eheka",
  "search_header": "Eheka {search_engine_name} ndive",
  "search_web_placeholder": "Ñandutivevépe Jeheka",
  "section_disclaimer_topstories": "Mba'erechapyrã ñandutivevepegua ojeiporavóva ndéve g̃uarã ojejesareko rupi remoñe'ẽva jepi rehe. Pocket guive ha'éva ko'ág̃a Mozilla mba'e.",
  "section_disclaimer_topstories_linktext": "Eikuaave mba'éichapa oiko.",
  "section_disclaimer_topstories_buttontext": "Oĩma, hesakãma chéve",
  "prefs_home_header": "Kuatiarogue retepy Firefox ñepyrũháme",
  "prefs_home_description": "Eiporavo mba’e retepýpa eipota Firefox mba’erechaha ñepyrũháme.",
  "prefs_content_discovery_description": "Content Discovery Firefox kuatiarogue ñepyrũme ohechaukakuaa tetepy oikóva ha iporãva ñandutípe g̃uarã.",
  "prefs_section_rows_option": "{num} rysýi; {num} rysýi",
  "prefs_search_header": "Ñandutípe jeheka",
  "prefs_topsites_description": "Umi tenda ojeikeveha",
  "prefs_topstories_description2": "Iporãvéva ñanduti retepy, oñemomba’éva ndéve g̃uarã",
  "prefs_topstories_options_sponsored_label": "Tembiasakue jehepyme'ẽguáva",
  "prefs_topstories_sponsored_learn_more": "Kuaave",
  "prefs_highlights_description": "Tenda jeporavopy eñongatu térã eike hague",
  "prefs_highlights_options_visited_label": "Tenda jeikepyre",
  "prefs_highlights_options_download_label": "Oñemboguejy ramovéva",
  "prefs_highlights_options_pocket_label": "Kuatiarogue ñongatupyre Pocket-pe",
  "prefs_snippets_description": "Mozilla ha Firefox ñembohekopyahu",
  "settings_pane_button_label": "Eñemomba'e ne Tendayke Pyahu roguére",
  "settings_pane_topsites_header": "Tenda Ojeikevéva",
  "settings_pane_highlights_header": "Mba'erechapyrã",
  "settings_pane_highlights_options_bookmarks": "Techaukaha",
  "settings_pane_snippets_header": "Mba'epehẽ",
  "edit_topsites_button_text": "Mbosako'i",
  "edit_topsites_edit_button": "Embosako'i ko tenda",
  "topsites_form_add_header": "Tenda Pyahu Ojeikevéva",
  "topsites_form_edit_header": "Tenda Ojeikevéva Mbosako'i",
  "topsites_form_title_label": "Teratee",
  "topsites_form_title_placeholder": "Ehai herarã",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL ra’anga ñemomba’etepyre",
  "topsites_form_url_placeholder": "Ehai térã emboja peteĩ URL",
  "topsites_form_use_image_link": "Ta’anga ñemomba’etepyre…",
  "topsites_form_preview_button": "Jehecha ypy",
  "topsites_form_add_button": "Embojoapy",
  "topsites_form_save_button": "Ñongatu",
  "topsites_form_cancel_button": "Heja",
  "topsites_form_url_validation": "Oñeikotevẽ URL oiko porãva",
  "topsites_form_image_validation": "Ta’anga nehenyhẽkuái. Eipuru peteĩ URL iñambuéva.",
  "pocket_read_more": "Ñe'ẽmbyrã Ojehayhuvéva:",
  "pocket_read_even_more": "Ahechaseve Mombe'upy",
  "pocket_more_reccommendations": "Hetave je’eporã",
  "pocket_how_it_works": "Mba’éichapa omba’apo",
  "pocket_cta_button": "Eguereko Pocket",
  "pocket_cta_text": "Eñongatu umi eipotáva tembiasakue Pocket-pe ha emombarete ne akã ñemoñe’ẽ ha’evévape.",
  "highlights_empty_state": "Eñepyrũ eikundaha ha rohechaukáta ndéve mba'ehai, mba'erecharã oĩva ha ambue ñandutirenda reikeva'ekue ýrõ rembotechaukava'ekue.",
  "topstories_empty_state": "Ko'ág̃a reikuaapáma ipyahúva. Eikejey ag̃ave ápe eikuaávo mombe'upy pyahu {provider} oikuave'ẽva ndéve. Ndaikatuvéima reha'ãrõ? Eiporavo peteĩ ñe'ẽmbyrã ha emoñe'ẽve oĩvéva ñande yvy ape ári.",
  "error_fallback_default_info": "Ema'ẽ, mba’épa osẽvai henyhẽnguévo ko tetepy.",
  "error_fallback_default_refresh_suggestion": "Kuatiarogue mbopiro’y eñepyrũjey hag̃ua",
  "section_menu_action_remove_section": "Emboguete vore",
  "section_menu_action_collapse_section": "Embopytupa vore",
  "section_menu_action_expand_section": "Emyasãi vore",
  "section_menu_action_manage_section": "Eñagareko vorére",
  "section_menu_action_manage_webext": "Emongu'e jepysokue",
  "section_menu_action_add_topsite": "Embojuaju Tenda ojeikeveha",
  "section_menu_action_add_search_engine": "Embojuaju hekaha",
  "section_menu_action_move_up": "Jupi",
  "section_menu_action_move_down": "Guejy",
  "section_menu_action_privacy_notice": "Marandu’i ñemiguáva",
  "firstrun_title": "Egueraha Firefox nendive",
  "firstrun_content": "Eike nde techaukaha, tembiasakue, ñe’ẽñemi ha ambueve ñemoĩporã opaite nde mba’e’okápe.",
  "firstrun_learn_more_link": "Eikuaave Firefox Accounts rehegua",
  "firstrun_form_header": "Emoinge ne ñandutiveve",
  "firstrun_form_sub_header": "eike hag̃ua Firefox Sync-pe.",
  "firstrun_email_input_placeholder": "Ñandutiveve",
  "firstrun_invalid_input": "Eikotevẽ peteĩ ñanduti veve oikóva",
  "firstrun_extra_legal_links": "Ejapóva, emoneĩ ko'ã {terms} ha {privacy}.",
  "firstrun_terms_of_service": "Mba'epytyvõrã ñemboguata",
  "firstrun_privacy_notice": "Ñemigua purureko",
  "firstrun_continue_to_login": "Eku'ejey",
  "firstrun_skip_login": "Ehejánte kóva",
  "context_menu_title": "Eike poravorãme"
};
